@@ -31,6 +31,7 @@ func getStartupScriptPackage(image, pkgManager string) *computeApi.MetadataItems
 		wantRemove := "vim"
 		ss = `set -x
 # install the package we want removed
+apt-get update
 apt-get -y install %[2]s
 # remove the package we want installed
 apt-get -y remove %[3]s
@@ -57,7 +58,7 @@ while true; do
   sleep 10
 done`
 
-		ss = fmt.Sprintf(ss, utils.InstallOSConfigDeb(), wantRemove, wantInstall, packageInstalled, packageNotInstalled)
+		ss = fmt.Sprintf(ss, utils.InstallOSConfigDeb(image), wantRemove, wantInstall, packageInstalled, packageNotInstalled)
 		key = "startup-script"
 
 	case "deb":
@@ -81,7 +82,7 @@ while true; do
   fi
   sleep 10
 done`
-		ss = fmt.Sprintf(ss, utils.InstallOSConfigDeb(), wantInstall[0], wantInstall[1], packageInstalled)
+		ss = fmt.Sprintf(ss, utils.InstallOSConfigDeb(image), wantInstall[0], wantInstall[1], packageInstalled)
 		key = "startup-script"
 
 	case "yum":
@@ -241,7 +242,7 @@ while true; do
   sleep 10
 done`
 
-		ss = fmt.Sprintf(ss, utils.InstallOSConfigDeb(), packageName, packageInstalled)
+		ss = fmt.Sprintf(ss, utils.InstallOSConfigDeb(image), packageName, packageInstalled)
 		key = "startup-script"
 
 	case "yum":
@@ -331,7 +332,7 @@ curl -X PUT --data "1" $uri -H "Metadata-Flavor: Google"`, fileExists)
 
 	switch pkgManager {
 	case "apt":
-		ss = fmt.Sprintf(linux, dnePath, utils.InstallOSConfigDeb(), fileDNE)
+		ss = fmt.Sprintf(linux, dnePath, utils.InstallOSConfigDeb(image), fileDNE)
 		for _, p := range wantPaths {
 			ss += fmt.Sprintf(linuxCheck, p)
 		}
@@ -424,7 +425,7 @@ curl -X PUT --data "1" $uri -H "Metadata-Flavor: Google"`, fileExists)
 
 	switch pkgManager {
 	case "apt":
-		ss = linux + utils.InstallOSConfigDeb() + linuxChecks + linuxEnd
+		ss = linux + utils.InstallOSConfigDeb(image) + linuxChecks + linuxEnd
 		key = "startup-script"
 
 	case "yum":
