@@ -34,7 +34,6 @@ var (
 sed -i 's/repo_gpgcheck=1/repo_gpgcheck=0/g' /etc/yum.repos.d/google-cloud.repo
 sleep 10
 systemctl stop google-osconfig-agent
-stop -q -n google-osconfig-agent  # required for EL6
 while ! yum install -y google-osconfig-agent; do
 if [[ n -gt 3 ]]; then
   exit 1
@@ -42,8 +41,7 @@ fi
 n=$[$n+1]
 sleep 5
 done
-systemctl start google-osconfig-agent
-start -q -n google-osconfig-agent  # required for EL6` + CurlPost
+systemctl start google-osconfig-agent` + CurlPost
 
 	zypperInstallAgent = `
 sleep 10
@@ -94,7 +92,7 @@ baseurl=https://packages.cloud.google.com/yum/repos/google-osconfig-agent-%s-%s
 enabled=1
 gpgcheck=%d
 gpgkey=https://packages.cloud.google.com/yum/doc/yum-key.gpg
-	   https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg
+           https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg
 EOM`
 
 	zypperRepoSetup = `
@@ -105,23 +103,29 @@ baseurl=https://packages.cloud.google.com/yum/repos/google-osconfig-agent-%s-%s
 enabled=1
 gpgcheck=%d
 gpgkey=https://packages.cloud.google.com/yum/doc/yum-key.gpg
-	   https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg
+           https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg
 EOM`
 )
 
 // InstallOSConfigDeb installs the osconfig agent on deb based systems.
-func InstallOSConfigDeb() string {
+func InstallOSConfigDeb(image string) string {
 	if config.AgentRepo() == "" {
 		return CurlPost
 	}
+	osName := getDebOsName(image)
 	return fmt.Sprintf(`
 sleep 10
 systemctl stop google-osconfig-agent
-echo 'deb http://packages.cloud.google.com/apt google-osconfig-agent-%s main' >> /etc/apt/sources.list
+
+# install gnupg2 if not exist
+apt-get update
+apt-get install -y gnupg2
+
+echo 'deb http://packages.cloud.google.com/apt google-osconfig-agent-%s-%s main' >> /etc/apt/sources.list
 curl https://packages.cloud.google.com/apt/doc/apt-key.gpg | apt-key add -
 apt-get update
 apt-get install -y google-osconfig-agent
-systemctl start google-osconfig-agent`+CurlPost, config.AgentRepo())
+systemctl start google-osconfig-agent`+CurlPost, osName, config.AgentRepo())
 }
 
 // InstallOSConfigGooGet installs the osconfig agent on Windows systems.
@@ -151,7 +155,21 @@ func InstallOSConfigSUSE() string {
 	return fmt.Sprintf(zypperRepoSetup+zypperInstallAgent, "el8", config.AgentRepo(), 0)
 }
 
-// InstallOSConfigEL8 installs the osconfig agent on el8 based systems.
+// InstallOSConfigEL9 installs the osconfig agent on el9 based systems. (RHEL)
+func InstallOSConfigEL9() string {
+	if config.AgentRepo() == "" {
+		return CurlPost
+	}
+	if config.AgentRepo() == "stable" {
+		return yumInstallAgent
+	}
+	if config.AgentRepo() == "staging" {
+		return fmt.Sprintf(yumRepoSetup+yumInstallAgent, "el9", config.AgentRepo(), 1)
+	}
+	return fmt.Sprintf(yumRepoSetup+yumInstallAgent, "el9", config.AgentRepo(), 0)
+}
+
+// InstallOSConfigEL8 installs the osconfig agent on el8 based systems. (RHEL)
 func InstallOSConfigEL8() string {
 	if config.AgentRepo() == "" {
 		return CurlPost
@@ -179,117 +197,140 @@ func InstallOSConfigEL7() string {
 	return fmt.Sprintf(yumRepoSetup+yumInstallAgent, "el7", config.AgentRepo(), 0)
 }
 
-// InstallOSConfigEL6 installs the osconfig agent on el6 based systems.
-func InstallOSConfigEL6() string {
-	if config.AgentRepo() == "" {
-		return CurlPost
+// containsAnyOf checks if a string contains any substring from a given list.
+func containsAnyOf(str string, substrings []string) bool {
+	for _, substring := range substrings {
+		if strings.Contains(str, substring) {
+			return true
+		}
 	}
-	if config.AgentRepo() == "stable" {
-		return yumInstallAgent
-	}
-	if config.AgentRepo() == "staging" {
-		return fmt.Sprintf(yumRepoSetup+yumInstallAgent, "el6", config.AgentRepo(), 1)
-	}
-	return fmt.Sprintf(yumRepoSetup+yumInstallAgent, "el6", config.AgentRepo(), 0)
+	return false
 }
 
 // InstallOSConfigEL installs the osconfig agent on el based systems.
 func InstallOSConfigEL(image string) string {
+	imageName := path.Base(image)
 	switch {
-	case strings.Contains(path.Base(image), "8"):
+	case image == "9" || containsAnyOf(imageName, []string{"rhel-9", "rhel-sap-9", "centos-stream-9", "rocky-linux-9"}):
+		return InstallOSConfigEL9()
+	case image == "8" || containsAnyOf(imageName, []string{"rhel-8", "rhel-sap-8", "centos-stream-8", "rocky-linux-8"}):
 		return InstallOSConfigEL8()
-	case strings.Contains(path.Base(image), "7"):
+	case image == "7" || containsAnyOf(imageName, []string{"rhel-7", "rhel-sap-7", "centos-7"}):
 		return InstallOSConfigEL7()
-	case strings.Contains(path.Base(image), "6"):
-		return InstallOSConfigEL6()
+
 	}
 	return ""
 }
 
-// DowngradeAptImages is a single image that are used for testing downgrade case with apt-get
-var DowngradeAptImages = map[string]string{
-	"debian-cloud/debian-10": "projects/debian-cloud/global/images/family/debian-10",
+// getDebOsType returns the equivalent os_name for deb version (e.g. debian-11 --> bullseye)
+func getDebOsName(image string) string {
+	imageName := path.Base(image)
+	switch {
+	case image == "10" || containsAnyOf(imageName, []string{"debian-10", "buster"}):
+		return "buster"
+	case image == "11" || containsAnyOf(imageName, []string{"debian-11", "bullseye"}):
+		return "bullseye"
+	case image == "12" || containsAnyOf(imageName, []string{"debian-12", "bookworm"}):
+		return "bookworm"
+	}
+	return ""
 }
 
-// HeadAptImages is a map of names to image paths for public image families that use APT.
-var HeadAptImages = map[string]string{
+// DowngradeBullseyeAptImages is a single image that are used for testing downgrade case with apt-get
+var DowngradeBullseyeAptImages = map[string]string{
+	"debian-cloud/debian-11": "projects/debian-cloud/global/images/debian-11-bullseye-v20231010",
+}
+
+// HeadBusterAptImages empty for now as debian-10 wil reach EOL and some of its repos are not reachable anymore.
+var HeadBusterAptImages = map[string]string{
+	// Debian images.
+}
+
+// HeadBullseyeAptImages is a map of names to image paths for public debian-11 images
+var HeadBullseyeAptImages = map[string]string{
 	// Debian images.
-	"debian-cloud/debian-10": "projects/debian-cloud/global/images/family/debian-10",
 	"debian-cloud/debian-11": "projects/debian-cloud/global/images/family/debian-11",
-
-	// Ubuntu images.
-	"ubuntu-os-cloud/ubuntu-1804-lts": "projects/ubuntu-os-cloud/global/images/family/ubuntu-1804-lts",
-	"ubuntu-os-cloud/ubuntu-2004-lts": "projects/ubuntu-os-cloud/global/images/family/ubuntu-2004-lts",
-	"ubuntu-os-cloud/ubuntu-2204-lts": "projects/ubuntu-os-cloud/global/images/family/ubuntu-2204-lts",
-
-	// Proposed Ubuntu images.
-	"ubuntu-os-cloud-image-proposed/ubuntu-1804-lts": "projects/ubuntu-os-cloud-image-proposed/global/images/family/ubuntu-1804-lts",
-	"ubuntu-os-cloud-image-proposed/ubuntu-2004-lts": "projects/ubuntu-os-cloud-image-proposed/global/images/family/ubuntu-2004-lts",
 }
 
-// OldAptImages is a map of names to image paths for old (deprecated) images that use APT.
-var OldAptImages = map[string]string{
+// HeadBookwormAptImages is a map of names to image paths for public debian-12 images
+var HeadBookwormAptImages = map[string]string{
 	// Debian images.
-	"old/debian-10": "projects/debian-cloud/global/images/debian-10-buster-v20210512",
-
-	// Ubuntu images.
-	"old/ubuntu-1804-lts": "projects/ubuntu-os-cloud/global/images/ubuntu-1804-bionic-v20230131",
-	"old/ubuntu-2004-lts": "projects/ubuntu-os-cloud/global/images/ubuntu-2004-focal-v20230113",
+	"debian-cloud/debian-12": "projects/debian-cloud/global/images/family/debian-12",
 }
 
 // HeadSUSEImages is a map of names to image paths for public SUSE images.
 var HeadSUSEImages = map[string]string{
-	"suse-cloud/sles-12": "projects/suse-cloud/global/images/family/sles-12",
-	"suse-cloud/sles-15": "projects/suse-cloud/global/images/family/sles-15",
+	"suse-cloud/sles-12-sp5": "projects/suse-cloud/global/images/family/sles-12",
+	"suse-cloud/sles-15-sp5": "projects/suse-cloud/global/images/family/sles-15",
 
-	"opensuse-cloud/opensuse-leap": "projects/opensuse-cloud/global/images/family/opensuse-leap",
+	"suse-sap-cloud/sles-12-sp5-sap": "projects/suse-sap-cloud/global/images/family/sles-12-sp5-sap",
+	"suse-sap-cloud/sles-15-sp5-sap": "projects/suse-sap-cloud/global/images/family/sles-15-sp5-sap",
+
+	"suse-sap-cloud/sles-15-sp5-hardened-sap": "projects/suse-sap-cloud/global/images/family/sles-sap-15-sp5-hardened",
+
+	"opensuse-cloud/opensuse-leap-15": "projects/opensuse-cloud/global/images/family/opensuse-leap",
 }
 
 // OldSUSEImages is a map of names to image paths for old SUSE images.
 var OldSUSEImages = map[string]string{
-	"old/sles-12": "projects/compute-image-tools-test/global/images/sles-12-sp5-v20221104-x86-64",
-	"old/sles-15": "projects/compute-image-tools-test/global/images/sles-15-sp4-v20221104-x86-64",
-
-	"old/opensuse-leap": "projects/opensuse-cloud/global/images/opensuse-leap-15-4-v20220831-x86-64",
+	"old/sles-15-sp1-sap": "projects/suse-sap-cloud/global/images/sles-15-sp1-sap-v20221108-x86-64",
+	"old/sles-15-sp2-sap": "projects/suse-sap-cloud/global/images/sles-15-sp2-sap-v20221108-x86-64",
+	"old/sles-15-sp3-sap": "projects/suse-sap-cloud/global/images/sles-15-sp3-sap-v20221108-x86-64",
+	"old/sles-15-sp4-sap": "projects/suse-sap-cloud/global/images/sles-15-sp4-sap-v20230623-x86-64",
 }
 
-// HeadEL6Images is a map of names to image paths for public EL6 images, we use the last
-// published image here as EL6 is EOL.
-// TODO: Either remove support for el6 or move this to a deprected test suite.
-var HeadEL6Images = map[string]string{
-	"rhel-cloud/rhel-6": "projects/rhel-cloud/global/images/rhel-6-v20201112",
-}
-
-// OldEL6Images is a map of names to image paths for old EL6 images.
-var OldEL6Images = map[string]string{
-	"old/rhel-6": "projects/rhel-cloud/global/images/rhel-6-v20191014",
-}
-
-// HeadEL7Images is a map of names to image paths for public EL7 image families.
+// HeadEL7Images is a map of names to image paths for public EL7 image families. (RHEL, CentOS)
 var HeadEL7Images = map[string]string{
 	"centos-cloud/centos-7": "projects/centos-cloud/global/images/family/centos-7",
-	"rhel-cloud/rhel-7":     "projects/rhel-cloud/global/images/family/rhel-7",
+
+	"rhel-cloud/rhel-7": "projects/rhel-cloud/global/images/family/rhel-7",
+
+	"rhel-sap-cloud/rhel-7-9-sap": "projects/rhel-sap-cloud/global/images/family/rhel-7-9-sap-ha",
 }
 
 // OldEL7Images is a map of names to image paths for old EL7 images.
 var OldEL7Images = map[string]string{
-	"old/centos-7": "projects/centos-cloud/global/images/centos-7-v20210512",
-	"old/rhel-7":   "projects/rhel-cloud/global/images/rhel-7-v20210512",
+	// Currently empty
 }
 
-// HeadEL8Images is a map of names to image paths for public EL8 image families.
+// HeadEL8Images is a map of names to image paths for public EL8 image families. (RHEL, CentOS, Rocky)
 var HeadEL8Images = map[string]string{
-	"centos-cloud/centos-stream-8":    "projects/centos-cloud/global/images/family/centos-stream-8",
-	"rhel-cloud/rhel-8":               "projects/rhel-cloud/global/images/family/rhel-8",
-	"rocky-linux-cloud/rocky-linux-8": "projects/rocky-linux-cloud/global/images/family/rocky-linux-8",
+	"centos-cloud/centos-stream-8": "projects/centos-cloud/global/images/family/centos-stream-8",
+
+	"rhel-cloud/rhel-8": "projects/rhel-cloud/global/images/family/rhel-8",
+
+	"rhel-sap-cloud/rhel-8-4-sap": "projects/rhel-sap-cloud/global/images/family/rhel-8-4-sap-ha",
+	"rhel-sap-cloud/rhel-8-6-sap": "projects/rhel-sap-cloud/global/images/family/rhel-8-6-sap-ha",
+	"rhel-sap-cloud/rhel-8-8-sap": "projects/rhel-sap-cloud/global/images/family/rhel-8-8-sap-ha",
+
+	"rocky-linux-cloud/rocky-linux-8":               "projects/rocky-linux-cloud/global/images/family/rocky-linux-8",
+	"rocky-linux-cloud/rocky-linux-8-optimized-gcp": "projects/rocky-linux-cloud/global/images/family/rocky-linux-8-optimized-gcp",
 }
 
-// OldEL8Images is a map of names to image paths for old EL8 images.
+// OldEL8Images is a map of names to image paths for old EL8 images. (RHEL, CentOS, Rocky)
 var OldEL8Images = map[string]string{
-	"old/rhel-8": "projects/rhel-cloud/global/images/rhel-7-v20210512",
+	// Currently empty
 }
 
-// HeadELImages is a map of names to image paths for public EL image families.
+// HeadEL9Images is a map of names to image paths for public EL9 image families. (RHEL, CentOS, Rocky)
+var HeadEL9Images = map[string]string{
+	"centos-cloud/centos-stream-9": "projects/centos-cloud/global/images/family/centos-stream-9",
+
+	"rhel-cloud/rhel-9": "projects/rhel-cloud/global/images/family/rhel-9",
+
+	"rhel-sap-cloud/rhel-9-0-sap": "projects/rhel-sap-cloud/global/images/family/rhel-9-0-sap-ha",
+	"rhel-sap-cloud/rhel-9-2-sap": "projects/rhel-sap-cloud/global/images/family/rhel-9-2-sap-ha",
+
+	"rocky-linux-cloud/rocky-linux-9":               "projects/rocky-linux-cloud/global/images/family/rocky-linux-9",
+	"rocky-linux-cloud/rocky-linux-9-optimized-gcp": "projects/rocky-linux-cloud/global/images/family/rocky-linux-9-optimized-gcp",
+}
+
+// OldEL9Images is a map of names to image paths for old EL9 images. (RHEL, CentOS, Rocky)
+var OldEL9Images = map[string]string{
+	// Currently empty
+}
+
+// HeadELImages is a map of names to image paths for public EL image families. (RHEL, CentOS, Rocky)
 var HeadELImages = func() (newMap map[string]string) {
 	newMap = make(map[string]string)
 	for k, v := range HeadEL7Images {
@@ -298,29 +339,45 @@ var HeadELImages = func() (newMap map[string]string) {
 	for k, v := range HeadEL8Images {
 		newMap[k] = v
 	}
+	for k, v := range HeadEL9Images {
+		newMap[k] = v
+	}
+	return
+}()
+
+// HeadAptImages is a map of names to image paths for public EL image families. (RHEL, CentOS, Rocky)
+var HeadAptImages = func() (newMap map[string]string) {
+	newMap = make(map[string]string)
+	for k, v := range HeadBusterAptImages {
+		newMap[k] = v
+	}
+	for k, v := range HeadBullseyeAptImages {
+		newMap[k] = v
+	}
+	for k, v := range HeadBookwormAptImages {
+		newMap[k] = v
+	}
 	return
 }()
 
 // HeadWindowsImages is a map of names to image paths for public Windows image families.
 var HeadWindowsImages = map[string]string{
-	"windows-cloud/windows-2012-r2":      "projects/windows-cloud/global/images/family/windows-2012-r2",
-	"windows-cloud/windows-2012-r2-core": "projects/windows-cloud/global/images/family/windows-2012-r2-core",
-	"windows-cloud/windows-2016":         "projects/windows-cloud/global/images/family/windows-2016",
-	"windows-cloud/windows-2016-core":    "projects/windows-cloud/global/images/family/windows-2016-core",
-	"windows-cloud/windows-2019":         "projects/windows-cloud/global/images/family/windows-2019",
-	"windows-cloud/windows-2019-core":    "projects/windows-cloud/global/images/family/windows-2019-core",
-	"windows-cloud/windows-2022":         "projects/windows-cloud/global/images/family/windows-2022",
-	"windows-cloud/windows-2022-core":    "projects/windows-cloud/global/images/family/windows-2022-core",
+	"windows-cloud/windows-2016":      "projects/windows-cloud/global/images/family/windows-2016",
+	"windows-cloud/windows-2016-core": "projects/windows-cloud/global/images/family/windows-2016-core",
+	"windows-cloud/windows-2019":      "projects/windows-cloud/global/images/family/windows-2019",
+	"windows-cloud/windows-2019-core": "projects/windows-cloud/global/images/family/windows-2019-core",
+
+	// Testing of win-2022-dc disabled because of https://techcommunity.microsoft.com/t5/windows-server-for-it-pro/faulty-patches-on-server-2022/m-p/4028125
+
+	/*
+		"windows-cloud/windows-2022":         "projects/windows-cloud/global/images/family/windows-2022",
+		"windows-cloud/windows-2022-core":    "projects/windows-cloud/global/images/family/windows-2022-core",
+	*/
 }
 
 // OldWindowsImages is a map of names to image paths for old Windows images.
 var OldWindowsImages = map[string]string{
-	"old/windows-2012-r2":      "projects/windows-cloud/global/images/windows-server-2012-r2-dc-v20210309",
-	"old/windows-2012-r2-core": "projects/windows-cloud/global/images/windows-server-2012-r2-dc-core-v20210309",
-	"old/windows-2016":         "projects/windows-cloud/global/images/windows-server-2016-dc-v20210309",
-	"old/windows-2016-core":    "projects/windows-cloud/global/images/windows-server-2016-dc-core-v20210309",
-	"old/windows-2019":         "projects/windows-cloud/global/images/windows-server-2019-dc-v20210309",
-	"old/windows-2019-core":    "projects/windows-cloud/global/images/windows-server-2019-dc-core-v20210309",
+	// Currently empty
 }
 
 // HeadCOSImages is a map of names to image paths for public COS image families.
